@@ -5,7 +5,7 @@ use strict;
 
 # ABSTRACT: A simple LDAP-based credentials validation plugin for Net::Squid::Auth::Engine
 
-our $VERSION = '0.1.83'; # VERSION
+our $VERSION = '0.1.84';    # VERSION
 
 use Carp;
 use Net::LDAP 0.4001;
@@ -120,7 +120,7 @@ Net::Squid::Auth::Plugin::SimpleLDAP - A simple LDAP-based credentials validatio
 
 =head1 VERSION
 
-version 0.1.83
+version 0.1.84
 
 =head1 SYNOPSIS
 
@@ -202,25 +202,6 @@ as parameters and returns a boolean indicating if the credentials are valid
 
 Accessor for a configuration setting given by key.
 
-=head1 SEE ALSO
-
-=over 4
-
-=item *
-L<Net::Squid::Auth::Engine>, L<Net::LDAP>, L<Scalar::Util>
-
-=item *
-RFC 4515 - Lightweight Directory Access Protocol (LDAP): String Representation of Search Filters
-
-L<http://www.faqs.org/rfcs/rfc4515.html>
-
-=item *
-RFC 4519 - Lightweight Directory Access Protocol (LDAP): Schema for User Applications
-
-L<http://www.faqs.org/rfcs/rfc4519.html>
-
-=back
-
 =head1 ACKNOWLEDGEMENTS
 
 Luis "Fields" Motta Campos C<< <lmc at cpan.org> >>, who could now say:
@@ -231,18 +212,7 @@ To what I'd reply:
 
 "Only a master of Perl, Fields"
 
-=head1 AUTHOR
-
-Alexei Znamensky <russoz@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2011 by Alexei Znamensky.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -271,7 +241,7 @@ L<http://search.cpan.org/dist/Net-Squid-Auth-Plugin-SimpleLDAP>
 
 AnnoCPAN
 
-The AnnoCPAN is a website that allows community annonations of Perl module documentation.
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
 
 L<http://annocpan.org/dist/Net-Squid-Auth-Plugin-SimpleLDAP>
 
@@ -311,12 +281,16 @@ L<http://www.cpantesters.org/distro/N/Net-Squid-Auth-Plugin-SimpleLDAP>
 
 CPAN Testers Matrix
 
-The CPAN Testers Matrix is a website that provides a visual way to determine what Perls/platforms PASSed for a distribution.
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
 
 L<http://matrix.cpantesters.org/?dist=Net-Squid-Auth-Plugin-SimpleLDAP>
 
 =back
 
+=head2 Email
+
+You can email the author of this module at C<RUSSOZ at cpan.org> asking for help with any problems you have.
+
 =head2 Internet Relay Chat
 
 You can get live help by using IRC ( Internet Relay Chat ). If you don't know what IRC is,
@@ -330,27 +304,41 @@ those networks/channels and get help:
 
 irc.perl.org
 
-You can connect to the server at 'irc.perl.org' and join this channel: #sao-paulo.pm to get help.
+You can connect to the server at 'irc.perl.org' and join this channel: #sao-paulo.pm then talk to this person for help: russoz.
 
 =back
 
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests by email to C<bug-net-squid-auth-plugin-simpleldap at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Net-Squid-Auth-Plugin-SimpleLDAP>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<https://github.com/russoz/Net-Squid-Auth-Plugin-SimpleLDAP>
+
+  git clone https://github.com/russoz/Net-Squid-Auth-Plugin-SimpleLDAP.git
+
+=head1 AUTHOR
+
+Alexei Znamensky <russoz@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Alexei Znamensky.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS AND LIMITATIONS
 
-No bugs have been reported.
-
-Please report any bugs or feature requests through the web interface at
-L<http://github.com/russoz/Net-Squid-Auth-Plugin-SimpleLDAP/issues>.
-
-=head1 AVAILABILITY
-
-The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
-site near you, or see L<http://search.cpan.org/dist/Net-Squid-Auth-Plugin-SimpleLDAP/>.
-
-The development version lives at L<http://github.com/russoz/Net-Squid-Auth-Plugin-SimpleLDAP>
-and may be cloned from L<git://github.com/russoz/Net-Squid-Auth-Plugin-SimpleLDAP.git>.
-Instead of sending patches, please fork this project using the standard
-git and github infrastructure.
+You can make new bug reports, and view existing ones, through the
+web interface at L<http://rt.cpan.org>.
 
 =head1 DISCLAIMER OF WARRANTY
 
@@ -380,4 +368,3 @@ DAMAGES.
 
 __END__
 
-
